@@ -59,6 +59,14 @@ public:
         ScrollPageFull = 1,
     };
 
+    /** This enum describes semantic hints appearance
+     */
+    enum SemanticHints {
+        SemanticHintsNever = 0,
+        SemanticHintsURL = 1,
+        SemanticHintsAlways = 2,
+    };
+
     /** This enum describes the shapes used to draw the cursor in terminal
      * displays.
      */
